@@ -9,13 +9,13 @@ from typing import Coroutine, Optional, Tuple
 from asyncpy.tools import check_logger,get_logger
 from asyncpy.response import Response
 import async_timeout
-from inspect import iscoroutinefunction
+from inspect import iscoroutinefunction,getabsfile
 from asyncio.locks import Semaphore
 from types import AsyncGeneratorType
 import weakref
-from asyncpy import settings
 import traceback
 
+from asyncpy import settings
 
 
 
@@ -29,6 +29,7 @@ class Request(object):
     else:
         DEFAULT_REQUEST_CONFIG = settings.DEFAULT_REQUEST_CONFIG
 
+
     REQUEST_CONFIG = DEFAULT_REQUEST_CONFIG
     REQUEST_CONFIG["RETRY_FUNC"] = Coroutine
     REQUEST_CONFIG["VALID"] = Coroutine
@@ -43,7 +44,7 @@ class Request(object):
                 callback=None,encoding: Optional[str] = None,
                 headers: dict= None,
                 meta: dict = None,custom_settings: dict = None,
-                request_session=None,**aiohttp_kwargs,):
+                request_session=None,**aiohttp_kwargs):
         self.url = url
         self.method = method.upper()
         self.custom_settings = None
