@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
+
 """
 CREATE YOUR DEFAULT_CONFIG !
 
@@ -24,13 +25,11 @@ CONCURRENT_REQUESTS = 20
 
 
 MIDDLEWARE = [
-'demo_middleware.middleware',
+'middlewares.middleware',
             ]
 
 
-PIPELINES = [
-'pipelines.SpiderPipeline',
-            ]
+# PIPELINES = []
 
 
 
@@ -54,4 +53,4 @@ DEFAULT_REQUEST_CONFIG = {
 
 
 
-# USER_AGENT = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.122 Safari/537.36'
\ No newline at end of file
+USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3100.0 Safari/537.36"
\ No newline at end of file
