@@ -8,7 +8,7 @@ import weakref
 import traceback
 from datetime import datetime
 from functools import reduce
-from inspect import isawaitable
+from inspect import isawaitable,getabsfile
 from signal import SIGINT, SIGTERM
 from types import AsyncGeneratorType
 from aiohttp import ClientSession
@@ -18,9 +18,12 @@ from asyncpy.middleware import Middleware
 from asyncpy.request import Request
 from asyncpy.response import Response
 from asyncpy.tools import check_logger,get_logger
-from asyncpy.settings import CONCURRENT_REQUESTS
-from asyncpy import settings
 import importlib
+import sys
+
+
+
+
 
 
 try:
@@ -99,7 +102,7 @@ class Spider(SpiderHook):
     """
     name = None
     custom_settings = None
-
+    settings = None
     # Default values passing to each request object. Not implemented yet.
     headers: dict = None
     meta: dict = None
@@ -111,7 +114,7 @@ class Spider(SpiderHook):
 
     # Concurrency control
     worker_numbers: int = 2
-    concurrency: int = CONCURRENT_REQUESTS
+    concurrency:  int = None
 
     # Spider entry
     start_urls: list = None
@@ -119,10 +122,12 @@ class Spider(SpiderHook):
     # A queue to save coroutines
     worker_tasks: list = []
 
+
+
     def __init__(
         self,
         middleware: typing.Union[typing.Iterable, Middleware] = None,
-        pipelines:[]= None,
+        pipelines = None,
         loop=None,
         is_async_start: bool = False,
         cancel_tasks: bool = True,
@@ -135,6 +140,8 @@ class Spider(SpiderHook):
         :param is_async_start: start spider by using async
         :param spider_kwargs
         """
+
+
         if not isinstance(self.start_urls, collections.Iterable):
             raise ValueError(
                 "start_urls must be a Iterable object"
@@ -172,6 +179,12 @@ class Spider(SpiderHook):
         # async queue as a producer
         self.request_queue = asyncio.Queue()
 
+        if not self.settings:
+            from asyncpy import settings
+        global settings
+        if not self.concurrency:
+            self.concurrency =  settings.CONCURRENT_REQUESTS
+        print(self.concurrency)
         # semaphore, used for concurrency control
         self.sem = asyncio.Semaphore(self.concurrency)
 
@@ -205,9 +218,10 @@ class Spider(SpiderHook):
                         )
                     )
                 elif isinstance(callback_result, dict):
-                    # Process target item
-                    for pipeline in self.pipelines:
-                        pipel = pipeline()
+                    #  根据类型判断是否回调给 pipelines
+
+                    # for pipeline in self.pipelines:
+                        pipel = self.pipelines()
                         pipel.process_item(item=callback_result,spider_name=self.name)
 
                 else:
@@ -347,48 +361,51 @@ class Spider(SpiderHook):
     def start(
         cls,
         middleware: typing.Union[typing.Iterable, Middleware] = None,
-        pipelines:[]= None,
+        pipelines = None,
         loop=None,
         after_start=None,
         before_stop=None,
         close_event_loop=True,
-        **spider_kwargs,
-    ):
+        **spider_kwargs):
 
 
-        """
-        Start a spider
-        :param after_start: hook
-        :param before_stop: hook
-        :param middleware: customize middleware or a list of middleware
-        :param loop: event loop
-        :param close_event_loop: bool
-        :param spider_kwargs: Additional keyword args to initialize spider
-        :return: An instance of :cls:`Spider`
-        """
+        #print(getabsfile(cls))
+        # modles = importlib.import_module(cls.name)
+        # print(modles)
+
+        # global setting
+        # setting = modles.setting
+
+
+
+        # if 'MIDDLEWARE' in dir(setting):
+        #     mw_list = setting.MIDDLEWARE
+        #     if mw_list:
+        #         for path in mw_list:
+        #             clast = path.split('.')[0]
+        #             miast = path.split('.')[1]
+        #             middleware_path = getabsfile(setting).replace('setting.py',clast+'.py')
+
+
+
+        # pipelines_list = []
+        # if 'PIPELINES' in dir(setting):
+        #     pl_list = setting.PIPELINES
+        #     if pl_list:
+        #         for path in pl_list:
+        #             modlt = path.split('.')[0]
+        #             clast = path.split('.')[1]
+        #             pilelines_path = getabsfile(setting).replace('setting.py',modlt+'.py')
+        #             sys.path.append(pilelines_path)
+        #             ret = importlib.import_module(modlt)
+        #             pipelines = getattr(ret,clast)
+        #             pipelines_list.append(pipelines)
 
-        if 'MIDDLEWARE' in dir(settings):
-            mw_list = settings.MIDDLEWARE
-            if mw_list:
-                for path in mw_list:
-                    clast = path.split('.')[0]
-                    ret = importlib.import_module(clast)    # 动态导入爬虫模块
-                    middleware = ret.middleware
 
-        pipelines_list = []
-        if 'PIPELINES' in dir(settings):
-            pl_list = settings.PIPELINES
-            if pl_list:
-                for path in pl_list:
-                    modlt = path.split('.')[0]
-                    clast = path.split('.')[1]
-                    ret = importlib.import_module(modlt)
-                    pipelines = getattr(ret,clast)
-                    pipelines_list.append(pipelines)
 
 
         loop = loop or asyncio.new_event_loop()
-        spider_ins = cls(middleware=middleware, loop=loop, **spider_kwargs,pipelines=pipelines_list)
+        spider_ins = cls(middleware=middleware, loop=loop, **spider_kwargs,pipelines=pipelines)
 
         # Actually start crawling
         spider_ins.loop.run_until_complete(
@@ -549,7 +566,6 @@ class Spider(SpiderHook):
                     *self.worker_tasks, return_exceptions=True
                 )
                 for task_result in results:
-
                     if "CLOSESPIDER_TIMEOUT" in dir(settings):
                         date1 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
                         date1 = datetime.strptime(date1, "%Y-%m-%d %H:%M:%S")
